# arq

[![CI](https://github.com/targetaidev/arku/workflows/CI/badge.svg?event=push)](https://github.com/targetaidev/arku/actions?query=event%3Apush+branch%3Amaster+workflow%3ACI)
[![Coverage](https://codecov.io/gh/targetaidev/arku/branch/master/graph/badge.svg)](https://codecov.io/gh/targetaidev/arku)
[![pypi](https://img.shields.io/pypi/v/arq.svg)](https://pypi.python.org/pypi/arq)
[![versions](https://img.shields.io/pypi/pyversions/arq.svg)](https://github.com/targetaidev/arku)
[![license](https://img.shields.io/github/license/targetaidev/arku.svg)](https://github.com/targetaidev/arku/blob/master/LICENSE)

Fast job queuing and RPC in Python with asyncio and Redis.

See [documentation](https://arku.readthedocs.io) for more details.
